Crate temporalio_macros

Crate temporalio_macros 

Macros

fsm
Parses a DSL for defining finite state machines, and produces code implementing the StateMachine trait.

Attribute Macros

activities
Can be used to define Activities for invocation and execution. Using this macro requires that you also depend on the temporalio_sdk crate.
activity
Marks a method within an #[activities] impl block as an activity. This attribute is processed by the #[activities] macro and should not be used standalone.
init
Marks a method within a #[workflow_methods] impl block as the initialization method. This attribute is processed by the #[workflow_methods] macro and should not be used standalone.
query
Marks a method within a #[workflow_methods] impl block as a query handler. This attribute is processed by the #[workflow_methods] macro and should not be used standalone.
run
Marks a method within a #[workflow_methods] impl block as the main run method. This attribute is processed by the #[workflow_methods] macro and should not be used standalone.
signal
Marks a method within a #[workflow_methods] impl block as a signal handler. This attribute is processed by the #[workflow_methods] macro and should not be used standalone.
update
Marks a method within a #[workflow_methods] impl block as an update handler. This attribute is processed by the #[workflow_methods] macro and should not be used standalone.
update_validator
Marks a method within a #[workflow_methods] impl block as a validator for an update handler. This attribute is processed by the #[workflow_methods] macro and should not be used standalone.
workflow
Marks a struct as a workflow definition.
workflow_methods
Defines workflow methods for a workflow struct. Using this macro requires that you also depend on the temporalio_sdk crate.