#[activity_definitions]Expand description
Declares activities without providing implementations. Each method must omit the
ActivityContext parameter and have a body of exactly unimplemented!().
Intended for workflow crates that need typed activity declarations which are implemented elsewhere by a separate worker crate (or in another language).