#[workflow]Expand description
Marks a struct as a workflow definition.
This attribute can optionally specify a custom workflow name:
#[workflow(name = "my-custom-workflow")]
If no name is specified, the struct name is used as the workflow type name.
This attribute must be used in conjunction with #[workflow_methods] on an impl block.